aboutsummaryrefslogtreecommitdiffstats
path: root/src/qml/Qt6QmlMacros.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'src/qml/Qt6QmlMacros.cmake')
-rw-r--r--src/qml/Qt6QmlMacros.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/qml/Qt6QmlMacros.cmake b/src/qml/Qt6QmlMacros.cmake
index a6e2e52bdb..869b8c507b 100644
--- a/src/qml/Qt6QmlMacros.cmake
+++ b/src/qml/Qt6QmlMacros.cmake
@@ -28,7 +28,7 @@
# right location. (OPTIONAL)
#
# INSTALL_LOCATION: Intended installation directory for this module. If no
# value is supplied, the default installation path will be ${Qt6_DIR}/qml.
# (OPTIONAL).
#
# DO_NOT_INSTALL_METADATA: When present, will not install the supporting files.
@@ -157,7 +157,7 @@ function(qt6_add_qml_module target)
endif()
if (NOT arg_INSTALL_LOCATION)
- set(arg_INSTALL_LOCATION "${Qt6_DIR}/../../../qml/${arg_TARGET_PATH}")
+ set(arg_INSTALL_LOCATION "${INSTALL_QMLDIR}/${arg_TARGET_PATH}")
endif()
set_target_properties(${target}
@@ -28,7 +28,7 @@
#
# INSTALL_LOCATION: Intended installation directory for this module. If no
-# value is supplied, the default installation path will be ${Qt6_DIR}/qml.
+# value is supplied, the default installation path will be ${INSTALL_QMLDIR}.
# (OPTIONAL).
#